@@ -37,6 +37,9 @@
 #include "History.h"
 #include "Print.h"
 #include "Equation.h"
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 using namespace std;
 using namespace giac;
@@ -139,6 +142,7 @@ namespace xcas {
     "from",
     "fsi",
     "ftantque",
+    "function",
     "goto",
     "if",
     "jusqu_a",
@@ -170,6 +174,7 @@ namespace xcas {
     "true",
     "try",
     "until",
+    "var",
     "while",
     "xor"
   };
@@ -1608,7 +1613,7 @@ namespace xcas {
     w->set_modal();
     w->show();
     w->hotspot(w);
-    Fl::focus(w);
+    Fl::focus(cond);
     autosave_disabled=true;
     context * contextptr=get_context(ed);
     int r=-2;
@@ -1724,7 +1729,7 @@ namespace xcas {
     w->show();
     autosave_disabled=true;
     w->hotspot(w);
-    Fl::focus(w);
+    Fl::focus(loop);
     context * contextptr=get_context(ed);
     int r=-2;
     for (;;) {
@@ -1848,7 +1853,7 @@ namespace xcas {
     w->show();
     autosave_disabled=true;
     w->hotspot(w);
-    Fl::focus(w);
+    Fl::focus(name);
     context * contextptr=get_context(ed);
     int lang=language(contextptr);
     int r=-2;
