@@ -629,6 +629,10 @@ namespace giac {
   gen common_EXT(gen & a,gen & b,const vecteur * l,GIAC_CONTEXT){
     if (a==b)
       return a;
+    if (a.type==_FRAC)
+      return common_EXT(a._FRACptr->num,b,l,contextptr);
+    if (b.type==_FRAC)
+      return common_EXT(a,b._FRACptr->num,l,contextptr);
     // extract minimal polynomials
     gen a_orig(a),b_orig(b);
     gen a__VECT,b__VECT;
