@@ -577,7 +577,9 @@ namespace giac {
     H.subtype=_POINT__VECT;
     vecteur res;
     // Face 1 A B // C E=A+AB+AC
-    res.push_back(makevecteur(A,C,E,B));
+    res.push_back(makevecteur(A,B,E,C));
+    // Face 6 D G // F H
+    res.push_back(makevecteur(D,G,H,F));
     // Face 2 A C // D F=A+AC+AD
     res.push_back(makevecteur(A,D,F,C));
     // Face 3 A B // D G=A+AB+AD
@@ -586,8 +588,6 @@ namespace giac {
     res.push_back(makevecteur(B,E,H,G));
     // Face 5 C E // F H
     res.push_back(makevecteur(C,F,H,E));
-    // Face 6 D G // F H
-    res.push_back(makevecteur(D,G,H,F));
     return polyedre_face(res,attributs,contextptr);
   }
   gen _parallelepipede(const gen & args,GIAC_CONTEXT){
@@ -2136,7 +2136,7 @@ namespace giac {
       nystep=nxstep;
       nzstep=nxstep;
     }
-    gen ff(unfactored?f_orig:factor(f_orig,false,contextptr));
+    gen ff( (unfactored || has_num_coeff(f_orig))?f_orig:factor(f_orig,false,contextptr));
     return in_plotimplicit(ff,x,y,z,xmin,xmax,ymin,ymax,zmin,zmax,nxstep,nystep,nzstep,eps,attributs,contextptr);
   }
 
@@ -2284,6 +2284,93 @@ namespace giac {
   static define_unary_function_eval (__est_cospherique,&giac::_est_cospherique,_est_cospherique_s);
   define_unary_function_ptr5( at_est_cospherique ,alias_at_est_cospherique,&__est_cospherique,0,true);
 
+  gen in_convert3d(const gen & h0,GIAC_CONTEXT){
+    if (h0.type!=_VECT)
+      return h0;
+    // convert complex to 3d vectors
+    vecteur w=*h0._VECTptr;
+    gen r,I;
+    for (unsigned i=0;i<w.size();++i){
+      reim(w[i],r,I,contextptr);
+      w[i]=gen(makevecteur(r,I,0),_POINT__VECT);
+    }
+    return gen(w,h0.subtype);
+  }
+
+  gen convert3d(const gen & g,GIAC_CONTEXT){
+    if (g.type==_VECT)
+      return apply(g,convert3d,contextptr);
+    if (!g.is_symb_of_sommet(at_pnt))
+      return g;
+    gen h=g._SYMBptr->feuille;
+    if (h.type!=_VECT || h._VECTptr->size()<2)
+      return g;
+    vecteur v=*h._VECTptr;
+    gen h0=v.front();
+    if (h0.is_symb_of_sommet(at_curve)){
+      gen c=h0._SYMBptr->feuille;
+      if (c.type!=_VECT || c._VECTptr->size()<2)
+	return g;
+      vecteur vc=*c._VECTptr;
+      gen c0=vc[0];
+      gen c1=vc[1];
+      if (c0.type==_VECT && !c0._VECTptr->empty()){
+	vecteur v0=*c0._VECTptr;
+	gen r,i;
+	reim(v0[0],r,i,contextptr);
+	v0[0]=gen(makevecteur(r,i,0),_POINT__VECT);
+	vc[0]=gen(v0,c0.subtype);
+      }
+      vc[1]=in_convert3d(c1,contextptr);
+      h0=symbolic(at_curve,gen(vc,h0.subtype));
+      v.front()=h0;
+      h=gen(v,h.subtype);
+      return symbolic(at_pnt,h);
+    }
+    if (h0.is_symb_of_sommet(at_cercle)){
+      gen centre,rayon;
+      if (!centre_rayon(h0,centre,rayon,false,contextptr))
+	return gensizeerr(contextptr); // don't care about radius sign
+      double nstep=50.0;
+      gen tmin=0,tmax=2*M_PI;
+      if (h0.type==_VECT && h0._VECTptr->size()>4){
+	tmin=(*h0._VECTptr)[2];
+	tmax=(*h0._VECTptr)[3];
+      }
+      gen tstep=(tmax-tmin)/nstep;
+      vecteur curve;
+      for (int i=0;i<=nstep;++i){
+	gen t=tmin+i*tstep;
+	if (i==nstep){
+	  if (h0.type==_VECT && h0._VECTptr->size()>4)
+	    t=tmax;
+	  else
+	    t=tmin;
+	}
+	gen z=centre+rayon*exp(cst_i*t,contextptr),zx,zy;
+	reim(z,zx,zy,contextptr);
+	curve.push_back(gen(makevecteur(zx,zy,0),_POINT__VECT));
+      }
+      v[0]=gen(curve,_GROUP__VECT);
+      return symbolic(at_pnt,gen(v,h.subtype));
+    }
+    if (h0.type==_VECT){
+      v.front()=in_convert3d(h0,contextptr);
+      h=gen(v,h.subtype);
+      return symbolic(at_pnt,h);
+    }
+    gen r,i;
+    reim(h0,r,i,contextptr);
+    h0=gen(makevecteur(r,i,0),_POINT__VECT);
+    v[0]=h0;
+    h=gen(v,h.subtype);
+    return symbolic(at_pnt,h);    
+  }
+  static const char _convert3d_s []="convert3d";
+  static define_unary_function_eval (__convert3d,&giac::convert3d,_convert3d_s);
+  define_unary_function_ptr5( at_convert3d ,alias_at_convert3d,&__convert3d,0,true);
+
+
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
 #endif // ndef NO_NAMESPACE_GIAC
