@@ -185,10 +185,6 @@
 {"REVERSE",13,-124,0,0},
 {"ROUND",13,-124,0,0},
 {"ROWNORM",13,-124,0,0},
-{"RPN_CASE",13,85,0,0},
-{"RPN_FOR",13,85,0,0},
-{"RPN_LOCAL",13,85,0,0},
-{"RPN_WHILE",13,85,0,0},
 {"RREF",13,-124,0,0},
 {"RandSeed",13,77,0,0},
 {"Rank",13,9,0,0},
@@ -235,8 +231,6 @@
 {"UTPN",13,9,0,0},
 {"UTPT",13,9,0,0},
 {"Unarchiv",13,77,0,0| 1},
-{"VAS",13,9,0,0},
-{"VAS_positive",13,9,0,0},
 {"VIEWS",13,77,0,0| 1},
 {"WAIT",13,-124,0,0},
 {"XHMS",13,-124,0,0},
@@ -261,8 +255,6 @@
 {"additionally",13,9,0,0| 1},
 {"adjoint_matrix",13,9,0,0},
 {"affix",13,9,0,0},
-{"alg",13,9,0,0},
-{"algsubs",13,9,0,0},
 {"algvar",13,9,0,0},
 {"alog10",13,9,0,0},
 {"alors",13,49,0,0| 1},
@@ -280,7 +272,6 @@
 {"approx",13,9,0,0},
 {"arc",13,9,0,0| 1},
 {"arcLen",13,9,0,0},
-//{"archive",13,9,0,0},
 {"area",13,9,0,0},
 {"areaat",13,9,0,0| 1},
 {"areaatraw",13,9,0,0},
@@ -303,21 +294,14 @@
 {"atanh",13,9,0,0},
 {"atrig2ln",13,9,0,0},
 {"augment",13,9,0,0},
-{"autosimplify",13,9,0,0},
 {"avance",13,126,0,0},
 {"avgRC",13,9,0,0},
-{"back",13,9,0,0},
 {"background",13,9,0,0| 1},
 {"baisse_crayon",13,126,0,0},
 {"bar_plot",13,9,0,0},
-{"barplot",13,9,0,0},
 {"barycenter",13,9,0,0},
 {"basis",13,9,0,0},
 {"bernoulli",13,9,0,0},
-{"betad",13,9,0,0},
-{"betad_cdf",13,9,0,0},
-{"betad_icdf",13,9,0,0},
-{"bezier",13,9,0,0},
 {"bezout_entiers",13,9,0,0},
 {"binomial",13,9,0,0},
 {"binomial_cdf",13,9,0,0},
@@ -347,17 +331,8 @@
 {"canonical_form",13,9,0,0},
 {"cap",13,126,0,0},
 {"cas_setup",13,9,0,0},
-{"caseval",13,9,0,0| 1},
 {"cat",13,9,0,0},
-{"cauchy",13,9,0,0},
-{"cauchy_cdf",13,9,0,0},
-{"cauchy_icdf",13,9,0,0},
-{"cauchyd",13,9,0,0},
-{"cauchyd_cdf",13,9,0,0},
-{"cauchyd_icdf",13,9,0,0},
 {"cd",13,9,0,0},
-{"cdf",13,9,0,0},
-{"cdfplot",13,9,0,0},
 {"ceil",13,9,0,0},
 {"ceiling",13,9,0,0},
 {"cell",13,9,0,0},
@@ -373,10 +348,6 @@
 {"chisquare",13,9,0,0},
 {"chisquare_cdf",13,9,0,0},
 {"chisquare_icdf",13,9,0,0},
-{"chisquared",13,9,0,0},
-{"chisquared_cdf",13,9,0,0},
-{"chisquared_icdf",13,9,0,0},
-{"chisquaret",13,9,0,0},
 {"cholesky",13,9,0,0},
 {"choosebox",13,9,0,0| 1},
 {"chrem",13,9,0,0},
@@ -390,13 +361,11 @@
 {"col",13,9,0,0},
 {"colDim",13,9,0,0},
 {"colNorm",13,9,0,0},
-{"colSwap",13,9,0,0},
 {"coldim",13,9,0,0},
 {"collect",13,9,0,0},
 {"colnorm",13,9,0,0},
 {"color",13,9,0,0},
 {"colspace",13,9,0,0},
-{"colswap",13,9,0,0},
 {"comDenom",13,9,0,0},
 {"comb",13,9,0,0},
 {"combine",13,9,0,0},
@@ -406,11 +375,9 @@
 {"compare",13,9,0,0},
 {"complexroot",13,9,0,0},
 {"concat",13,9,0,0},
-{"cond",13,9,0,0},
 {"cone",13,9,0,0},
 {"conic",13,9,0,0},
 {"conj",13,9,0,0},
-{"conjugate_gradient",13,9,0,0},
 {"cont",13,9,0,0| 1},
 {"contains",13,9,0,0},
 {"content",13,9,0,0},
@@ -443,10 +410,9 @@
 {"crossproduct",13,9,0,0},
 {"csc",13,9,0,0},
 {"csolve",13,9,0,0| 1},
-//{"csv2gen",13,9,0,0},
+{"csv2gen",13,9,0,0},
 {"cube",13,9,0,0},
 {"cumSum",13,9,0,0},
-{"cumsum",13,9,0,0},
 {"cumulated_frequencies",13,9,0,0},
 {"curl",13,9,0,0| 1},
 {"current_sheet",13,9,0,0| 1},
@@ -457,7 +423,6 @@
 {"cycles2permu",13,9,0,0},
 {"cyclotomic",13,9,0,0},
 {"cylinder",13,9,0,0},
-{"czeros",13,9,0,0| 1},
 {"de",13,57,0,0| 1},
 {"deSolve",13,77,0,0| 1},
 {"debug",13,9,0,0| 1},
@@ -500,7 +465,6 @@
 {"dodecahedron",13,9,0,0},
 {"dot",13,9,0,0},
 {"dotP",13,9,0,0},
-{"dot_paper",13,9,0,0},
 {"dotprod",13,9,0,0},
 {"droit",13,9,0,0},
 {"droite_tangente",13,9,0,0},
@@ -520,7 +484,6 @@
 {"eigenvectors",13,9,0,0},
 {"eigenvects",13,9,0,0},
 {"element",13,9,0,0},
-{"eliminate",13,9,0,0},
 {"ellipse",13,9,0,0},
 {"entry",13,9,0,0},
 {"envelope",13,9,0,0},
@@ -553,14 +516,8 @@
 {"exp2pow",13,9,0,0},
 {"exp2trig",13,9,0,0},
 {"expexpand",13,9,0,0},
-{"exponential",13,9,0,0},
-{"exponential_cdf",13,9,0,0},
-{"exponential_icdf",13,9,0,0},
 {"exponential_regression",13,9,0,0},
 {"exponential_regression_plot",13,9,0,0},
-{"exponentiald",13,9,0,0},
-{"exponentiald_cdf",13,9,0,0},
-{"exponentiald_icdf",13,9,0,0},
 {"expr",13,9,0,0},
 {"extract_measure",13,9,0,0},
 {"ezgcd",13,9,0,0},
@@ -585,15 +542,10 @@
 {"fieldplot",13,9,0,0},
 {"filled",13,2,0,0},
 {"fin_enregistrement",13,126,0,0},
-{"find",13,9,0,0},
 {"findhelp",13,9,0,0| 1},
 {"fisher",13,9,0,0},
 {"fisher_cdf",13,9,0,0},
 {"fisher_icdf",13,9,0,0},
-{"fisherd",13,9,0,0},
-{"fisherd_cdf",13,9,0,0},
-{"fisherd_icdf",13,9,0,0},
-{"flatten",13,9,0,0},
 {"float",13,9,0,0},
 {"float2rational",13,9,0,0},
 {"floor",13,9,0,0},
@@ -609,47 +561,35 @@
 {"fracmod",13,9,0,0},
 {"frame_2d",13,9,0,0},
 {"frame_3d",13,9,0,0},
-{"frequencies",13,9,0,0},
-{"frobenius_norm",13,9,0,0},
 {"froot",13,9,0,0},
 {"fsolve",13,9,0,0| 1},
 {"funcplot",13,9,0,0| 1},
 {"function_diff",13,9,0,0},
 {"fxnd",13,9,0,0},
-{"gammad",13,9,0,0},
-{"gammad_cdf",13,9,0,0},
-{"gammad_icdf",13,9,0,0},
 {"gauche",13,9,0,0},
 {"gauss",13,9,0,0},
 {"gaussjord",13,9,0,0},
-{"gaussquad",13,9,0,0},
 {"gbasis",13,9,0,0},
 {"gcd",13,9,0,0},
 {"gcdex",13,9,0,0},
 {"genpoly",13,9,0,0},
 {"geo2d",13,9,0,0},
 {"geo3d",13,9,0,0},
-{"geometric",13,9,0,0},
-{"geometric_cdf",13,9,0,0},
-{"geometric_icdf",13,9,0,0},
 {"getDenom",13,9,0,0},
 {"getKey",13,9,0,0},
 {"getNum",13,9,0,0},
 {"getType",13,9,0,0},
-{"ggb_ang",13,9,0,0},
 {"giac",13,9,0,0},
 {"goto",13,77,0,0},
 {"grad",13,9,0,0| 1},
 {"gramschmidt",13,9,0,0},
 {"graph2tex",13,9,0,0},
 {"graph3d2tex",13,9,0,0},
-{"graph_scc",13,9,0,0},
 {"graphe",13,9,0,0| 1},
 {"graphe3d",13,9,0,0},
 {"graphe_suite",13,9,0,0},
 {"greduce",13,9,0,0},
 {"green",13,2,0,0},
-{"grid_paper",13,9,0,0},
 {"groupermu",13,9,0,0},
 {"hadamard",13,9,0,0},
 {"half_cone",13,9,0,0},
@@ -658,7 +598,6 @@
 {"halftan_hyp2exp",13,9,0,0},
 {"halt",13,9,0,0| 1},
 {"hamdist",13,9,0,0},
-{"harmonic",13,9,0,0},
 {"harmonic_conjugate",13,9,0,0},
 {"harmonic_division",13,9,0,0| 1},
 {"has",13,9,0,0},
@@ -688,7 +627,6 @@
 {"ibasis",13,9,0,0},
 {"ibpdv",13,9,0,0},
 {"ibpu",13,9,0,0},
-{"icdf",13,9,0,0},
 {"ichinrem",13,9,0,0},
 {"ichrem",13,9,0,0},
 {"icontent",13,9,0,0},
@@ -701,7 +639,6 @@
 {"ifactor",13,9,0,0},
 {"ifactors",13,9,0,0},
 {"ifft",13,9,0,0},
-//{"igamma",13,9,0,0},
 {"igcd",13,9,0,0},
 {"igcdex",13,9,0,0},
 {"ihermite",13,9,0,0},
@@ -717,7 +654,6 @@
 {"increment",13,9,0,0| 1},
 {"indets",13,9,0,0},
 {"inequationplot",13,9,0,0| 1},
-//{"inferieur_strict_sort",13,9,0,0},
 {"input",13,9,0,0| 1},
 {"inputform",13,9,0,0| 1},
 {"insmod",13,9,0,0},
@@ -746,22 +682,17 @@
 {"is_concyclic",13,9,0,0},
 {"is_conjugate",13,9,0,0},
 {"is_coplanar",13,9,0,0},
-{"is_cospherical",13,9,0,0},
 {"is_cycle",13,9,0,0},
 {"is_element",13,9,0,0},
 {"is_equilateral",13,9,0,0},
 {"is_harmonic",13,9,0,0},
 {"is_harmonic_circle_bundle",13,9,0,0},
 {"is_harmonic_line_bundle",13,9,0,0},
-{"is_included",13,9,0,0},
-//{"is_inside",13,9,0,0},
-{"is_isosceles",13,9,0,0},
 {"is_orthogonal",13,9,0,0},
 {"is_parallel",13,9,0,0},
 {"is_parallelogram",13,9,0,0},
 {"is_permu",13,9,0,0},
 {"is_perpendicular",13,9,0,0},
-{"is_polynomial",13,9,0,0},
 {"is_prime",13,9,0,0},
 {"is_pseudoprime",13,9,0,0},
 {"is_rectangle",13,9,0,0},
@@ -771,7 +702,6 @@
 {"isobarycenter",13,9,0,0},
 {"isom",13,9,0,0},
 {"isopolygon",13,9,0,0},
-{"isosceles_triangle",13,9,0,0| 1},
 {"isprime",13,9,0,0},
 {"ithprime",13,9,0,0},
 {"jacobi_symbol",13,9,0,0},
@@ -781,8 +711,6 @@
 {"kernel",13,9,0,0},
 {"keyboard",13,9,0,0},
 {"kill",13,9,0,0},
-{"kolmogorovd",13,9,0,0},
-{"kolmogorovt",13,9,0,0},
 {"l1norm",13,9,0,0},
 {"l2norm",13,9,0,0},
 {"label",13,77,0,0},
@@ -809,14 +737,12 @@
 {"lin",13,9,0,0},
 {"line",13,9,0,0| 1},
 {"line_inter",13,9,0,0},
-{"line_paper",13,9,0,0},
 {"line_segments",13,9,0,0},
 {"linear_interpolate",13,9,0,0},
 {"linear_regression",13,9,0,0},
 {"linear_regression_plot",13,9,0,0},
 {"lineariser",13,9,0,0},
 {"lineariser_trigo",13,9,0,0},
-{"linfnorm",13,9,0,0},
 {"linsolve",13,9,0,0| 1},
 {"lis",13,77,0,0| 1},
 {"lis_phrase",13,77,0,0| 1},
@@ -851,19 +777,16 @@
 {"maple2xcas",13,9,0,0| 1},
 {"maple_ifactors",13,9,0,0},
 {"maple_mode",13,9,0,0},
-{"markov",13,9,0,0},
 {"mat2list",13,9,0,0},
 {"mathml",13,9,0,0},
 {"matpow",13,9,0,0},
 {"matrix",13,9,0,0},
-{"matrix_norm",13,9,0,0},
 {"max",13,9,0,0},
 {"maxnorm",13,9,0,0},
 {"mean",13,9,0,0},
 {"median",13,9,0,0},
 {"median_line",13,9,0,0},
 {"member",13,9,0,0| 1},
-{"mgf",13,9,0,0},
 {"mid",13,9,0,0},
 {"midpoint",13,9,0,0},
 {"min",13,9,0,0},
@@ -882,7 +805,6 @@
 {"mult_c_conjugate",13,9,0,0| 1},
 {"mult_conjugate",13,9,0,0},
 {"multcrement",13,9,0,0| 1},
-{"multinomial",13,9,0,0},
 {"multiplier_conjugue",13,9,0,0},
 {"multiplier_conjugue_complexe",13,9,0,0},
 {"multiply",13,9,0,0},
@@ -894,9 +816,6 @@
 {"nPr",13,9,0,0},
 {"nSolve",13,9,0,0},
 {"ncols",13,9,0,0},
-{"negbinomial",13,9,0,0},
-{"negbinomial_cdf",13,9,0,0},
-{"negbinomial_icdf",13,9,0,0},
 {"newList",13,9,0,0},
 {"newMat",13,9,0,0},
 {"newton",13,9,0,0},
@@ -915,8 +834,6 @@
 {"normald_cdf",13,9,0,0},
 {"normald_icdf",13,9,0,0},
 {"normalize",13,9,0,0},
-{"normalt",13,9,0,0},
-{"nprimes",13,9,0,0},
 {"nrows",13,9,0,0},
 {"nuage_points",13,9,0,0},
 {"nullspace",13,9,0,0},
@@ -980,7 +897,6 @@
 {"plot3d",13,9,0,0},
 {"plot_style",13,9,0,0},
 {"plotarea",13,9,0,0},
-{"plotcdf",13,9,0,0},
 {"plotcontour",13,9,0,0| 1},
 {"plotdensity",13,9,0,0| 1},
 {"plotfield",13,9,0,0},
@@ -991,7 +907,6 @@
 {"plotode",13,9,0,0},
 {"plotparam",13,9,0,0| 1},
 {"plotpolar",13,9,0,0| 1},
-{"plotproba",13,9,0,0| 1},
 {"plotseq",13,9,0,0},
 {"pmin",13,9,0,0},
 {"pnt",13,9,0,0},
@@ -1010,8 +925,6 @@
 {"pole",13,9,0,0},
 {"poly2symb",13,9,0,0},
 {"polyEval",13,9,0,0},
-{"polygamma",13,9,0,0},
-{"polygon",13,9,0,0},
 {"polygone_rempli",13,126,0,0},
 {"polygonplot",13,9,0,0},
 {"polygonscatterplot",13,9,0,0},
@@ -1019,8 +932,6 @@
 {"polynomial_regression",13,9,0,0},
 {"polynomial_regression_plot",13,9,0,0},
 {"position",13,126,0,0},
-{"poslbdLMQ",13,9,0,0},
-{"posubLMQ",13,9,0,0},
 {"potential",13,9,0,0| 1},
 {"pour",13,56,0,0| 1},
 {"pow2exp",13,9,0,0},
@@ -1056,7 +967,7 @@
 {"quartile1",13,9,0,0},
 {"quartile3",13,9,0,0},
 {"quartiles",13,9,0,0},
-//{"quaternion",13,9,0,0},
+{"quaternion",13,9,0,0},
 {"quest",13,9,0,0},
 {"quo",13,9,0,0},
 {"quorem",13,9,0,0},
@@ -1069,26 +980,13 @@
 {"randMat",13,9,0,0},
 {"randNorm",13,9,0,0},
 {"randPoly",13,9,0,0},
-{"randbinomial",13,9,0,0},
-{"randchisquare",13,9,0,0},
-{"randchisquared",13,9,0,0},
 {"randexp",13,9,0,0},
-{"randfisher",13,9,0,0},
-{"randfisherd",13,9,0,0},
-{"randgeometric",13,9,0,0},
-{"randmarkov",13,9,0,0},
 {"randmatrix",13,9,0,0},
-{"randmultinomial",13,9,0,0},
-{"randnormald",13,9,0,0},
 {"randperm",13,9,0,0},
-{"randpoisson",13,9,0,0},
 {"randpoly",13,9,0,0},
-{"randstudent",13,9,0,0},
-{"randstudentd",13,9,0,0},
 {"randvector",13,9,0,0},
 {"rank",13,9,0,0},
 {"ranm",13,9,0,0},
-{"ranv",13,9,0,0},
 {"rassembler_trigo",13,9,0,0},
 {"rat_jordan",13,9,0,0},
 {"rat_jordan_block",13,9,0,0},
@@ -1100,29 +998,24 @@
 {"readrgb",13,9,0,0},
 {"readwav",13,9,0,0},
 {"real",13,9,0,0},
-{"realproot",13,9,0,0},
 {"realroot",13,9,0,0},
 {"reciprocation",13,9,0,0},
 {"rectangle",13,9,0,0| 1},
 {"rectangle_plein",13,126,0,0},
 {"rectangular2polar",13,9,0,0},
-{"rectangular2spherical",13,9,0,0},
 {"rectangular_coordinates",13,9,0,0},
 {"recule",13,126,0,0},
 {"red",13,2,0,0},
-{"redim",13,-124,0,0| 1},
 {"reduced_conic",13,9,0,0},
 {"reduced_quadric",13,9,0,0},
 {"ref",13,9,0,0},
 {"reflection",13,9,0,0},
-{"regroup",13,9,0,0},
 {"rem",13,9,0,0},
 {"remain",13,9,0,0},
 {"remove",13,9,0,0},
 {"remove_language",13,9,0,0},
 {"reorder",13,9,0,0},
 {"repete",13,77,0,0| 1},
-{"replace",13,-124,0,0| 1},
 {"reset_solve_counter",13,9,0,0},
 {"residue",13,9,0,0},
 {"resoudre",13,9,0,0| 1},
@@ -1139,7 +1032,6 @@
 {"rhs",13,9,0,0},
 {"right",13,9,0,0},
 {"right_triangle",13,9,0,0| 1},
-{"risch",13,9,0,0},
 {"rm_a_z",13,9,0,0},
 {"rm_all_vars",13,9,0,0},
 {"rmbreakpoint",13,9,0,0| 1},
@@ -1160,8 +1052,6 @@
 {"rowdim",13,9,0,0},
 {"rownorm",13,9,0,0},
 {"rowspace",13,9,0,0},
-{"rowswap",13,9,0,0},
-{"rpn",13,9,0,0},
 {"rref",13,9,0,0},
 {"rsolve",13,9,0,0| 1},
 {"saute",13,126,0,0},
@@ -1169,10 +1059,7 @@
 {"save_history",13,9,0,0},
 {"scalarProduct",13,9,0,0},
 {"scalar_product",13,9,0,0},
-{"scale",13,-124,0,0| 1},
-{"scaleadd",13,-124,0,0| 1},
 {"scatterplot",13,9,0,0},
-{"schur",13,9,0,0},
 {"sec",13,9,0,0},
 {"segment",13,9,0,0},
 {"select",13,9,0,0},
@@ -1211,16 +1098,12 @@
 {"snedecor",13,9,0,0},
 {"snedecor_cdf",13,9,0,0},
 {"snedecor_icdf",13,9,0,0},
-{"snedecord",13,9,0,0},
-{"snedecord_cdf",13,9,0,0},
-{"snedecord_icdf",13,9,0,0},
 {"solve",13,9,0,0| 1},
 {"solve_zero_extremum",13,9,0,0| 1},
 {"somme",13,9,0,0| 1},
 {"sommet",13,9,0,0},
 {"sort",13,9,0,0},
 {"sphere",13,9,0,0},
-{"spherical2rectangular",13,9,0,0},
 {"spline",13,9,0,0},
 {"split",13,9,0,0},
 {"spread2mathml",13,9,0,0},
@@ -1240,10 +1123,6 @@
 {"student",13,9,0,0},
 {"student_cdf",13,9,0,0},
 {"student_icdf",13,9,0,0},
-{"studentd",13,9,0,0},
-{"studentd_cdf",13,9,0,0},
-{"studentd_icdf",13,9,0,0},
-{"studentt",13,9,0,0},
 {"sturm",13,9,0,0},
 {"sturmab",13,9,0,0},
 {"sturmseq",13,9,0,0},
@@ -1251,16 +1130,11 @@
 {"submatrix",13,9,0,0},
 {"subst",13,9,0,0},
 {"substituer",13,9,0,0},
-{"subtype",13,9,0,0},
 {"sum",13,9,0,0| 1},
 {"sum_riemann",13,9,0,0},
 {"suppress",13,9,0,0},
 {"surd",13,9,0,0},
 {"svd",13,9,0,0},
-//{"svg",13,9,0,0},
-{"svl",13,9,0,0},
-{"swapcol",13,9,0,0},
-{"swaprow",13,9,0,0},
 {"switch_axes",13,9,0,0},
 {"sylvester",13,9,0,0},
 {"symb2poly",13,9,0,0},
@@ -1279,7 +1153,6 @@
 {"tangente",13,9,0,0},
 {"tanh",13,9,0,0},
 {"tantque",13,62,0,0| 1},
-{"taux_accroissement",13,9,0,0},
 {"taylor",13,9,0,0},
 {"tchebyshev1",13,9,0,0},
 {"tchebyshev2",13,9,0,0},
@@ -1301,7 +1174,6 @@
 {"translation",13,9,0,0},
 {"transpose",13,9,0,0},
 {"triangle",13,9,0,0},
-{"triangle_paper",13,9,0,0},
 {"triangle_plein",13,126,0,0},
 {"trig2exp",13,9,0,0},
 {"trigcos",13,9,0,0},
@@ -1314,16 +1186,9 @@
 {"tsimplify",13,9,0,0},
 {"type",13,9,0,0},
 {"ufactor",13,9,0,0},
-//{"ugamma",13,9,0,0},
 {"unapply",13,9,0,0| 1},
-//{"unarchive",13,9,0,0},
+{"unarchive",13,9,0,0},
 {"unarchive_ti",13,9,0,0},
-{"uniform",13,9,0,0},
-{"uniform_cdf",13,9,0,0},
-{"uniform_icdf",13,9,0,0},
-{"uniformd",13,9,0,0},
-{"uniformd_cdf",13,9,0,0},
-{"uniformd_icdf",13,9,0,0},
 {"unitV",13,9,0,0},
 {"unquote",13,9,0,0},
 {"usimplify",13,9,0,0},
@@ -1338,12 +1203,6 @@
 {"vertices_abca",13,9,0,0},
 {"vpotential",13,9,0,0| 1},
 {"watch",13,9,0,0| 1},
-{"weibull",13,9,0,0},
-{"weibull_cdf",13,9,0,0},
-{"weibull_icdf",13,9,0,0},
-{"weibulld",13,9,0,0},
-{"weibulld_cdf",13,9,0,0},
-{"weibulld_icdf",13,9,0,0},
 {"whattype",13,9,0,0},
 {"when",13,9,0,0| 1},
 {"white",13,2,0,0},
